netapp_ontap.resources.software_package_download API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.software_package_download`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Overview

You can use this API to download a software or firmware package from the server and to check the status of the software or firmware download.

## Examples

### Downloading the software package

The following example shows how to download the software or firmware package from an HTTP or FTP server. If required, provide the url, username, and password to start the download of the package to the cluster.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import SoftwarePackageDownload

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = SoftwarePackageDownload()
        resource.url = "http://server/package"
        resource.username = "admin"
        resource.password = "*********"
        resource.post(hydrate=True, return_timeout=0)
        print(resource)

Try it out

    SoftwarePackageDownload(
        {"password": "*********", "username": "admin", "url": "http://server/package"}
    )

The call to download the software or firmware package returns the job UUID, including a HAL link to retrieve details about the job. The job object includes a `state` field and a message to indicate the progress of the job. When the job is complete and the application is fully created, the message indicates success and the job `state` field is set to `success`.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Job

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Job(uuid="f587d316-5feb-11e8-b0e0-005056956dfc")
        resource.get()
        print(resource)

Try it out

    Job(
        {
            "message": "success",
            "_links": {
                "self": {"href": "/api/cluster/jobs/f587d316-5feb-11e8-b0e0-005056956dfc"}
            },
            "code": 0,
            "state": "success",
            "uuid": "f587d316-5feb-11e8-b0e0-005056956dfc",
            "description": "POST /api/cluster/software/download",
        }
    )

### Checking the progress of the software package being downloaded from an HTTP or FTP server

The following example shows how to retrieve the progress status of the software package that is being downloaded from a HTTP or FTP server.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import SoftwarePackageDownload

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = SoftwarePackageDownload()
        resource.get()
        print(resource)

Try it out

    SoftwarePackageDownload(
        {"message": "Package download in progress", "state": "running", "code": 10551382}
    )

### Learn more

- `DOC /cluster/software/download`

## Classes

`class SoftwarePackageDownload (*args, **kwargs)`

  Allows interaction with SoftwarePackageDownload objects on the host

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Methods

  `def get (self, **kwargs) -> NetAppResponse`

    Retrieves the software or firmware download status.

    ### Learn more

    - `DOC /cluster/software/download`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400 or if not all of the keys required are present and config.STRICT_GET has been set to True.

  `def post (self, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Downloads a software or firmware package from the server.

    ### Required properties

    - `url` - URL location of the software package

    ### Recommended optional parameters

    - `username` - Username of HTTPS/FTP server
    - `password` - Password of HTTPS/FTP server

    ### Related ONTAP commands

    - `cluster image package get`

    ### Learn more

    - `DOC /cluster/software/download`

    Send this object to the host as a creation request.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
    - `validate_schema`
`class SoftwarePackageDownloadSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the SoftwarePackageDownload object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `code: Size GET`

    Code returned corresponds to a download message.

    Example: 10551382

  `message: str GET`

    Download progress details.

    Example: Package download in progress

  `password: str POST`

    Password for download

    Example: admin_password

  `state: str GET`

    Download status of the package.

    Valid choices:

    - not_started
    - running
    - success
    - failure
  `url: str POST`

    HTTP or FTP URL of the package through a server

    Example: http://server/package

  `username: str POST`

    Username for download

    Example: admin